window.Gleam.initSearch([{"doc":"react_gleam","title":"react_gleam","content":"# react_gleam\n\nReact bindings for Gleam inspired by [Lustre](https://github.com/hayleigh-dot-dev/gleam-lustre/blob/main/src/lustre/attribute.gleam) and [ReasonReact](https://reasonml.github.io/reason-react/).\n\n---\n\n[![Package Version](https://img.shields.io/hexpm/v/react_gleam)](https://hex.pm/packages/react_gleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/react_gleam/)\n\nreact_gleam provides React bindings for [Gleam](https://gleam.run/) giving you a type safe, and expressive React experience out of the box.\n\n```gleam\nimport gleam/int\nimport react_gleam.{component, render}\nimport react_gleam/element.{Element, div, text}\nimport react_gleam/hook.{use_state}\nimport react_gleam/event.{on_click}\n\npub fn main() {\n  render(app(), &quot;#app&quot;)\n}\n\nfn app() -&gt; Element {\n  div(\n    [],\n    [\n      div([], [text(&quot;Welcome to Gleam React!&quot;)]),\n      greet(name: &quot;Joe&quot;),\n      counter(count: 6),\n    ],\n  )\n}\n\nfn greet(name name: String) -&gt; Element {\n  div([], [text(&quot;Hello &quot; &lt;&gt; name &lt;&gt; &quot;!&quot;)])\n}\n\nfn counter(count init_count: Int) -&gt; Element {\n  use &lt;- component()\n\n  let #(count, set_count) = use_state(fn(_) { init_count })\n\n  div(\n    [],\n    [\n      div([on_click(fn(_) { set_count(fn(prev) { prev + 1 }) })], [text(&quot;+&quot;)]),\n      div([], [text(int.to_string(count))]),\n      div([on_click(fn(_) { set_count(fn (prev) { prev - 1 }) })], [text(&quot;-&quot;)]),\n    ],\n  )\n}\n\n```\n\n## Hooks\n\n react_gleam supports the `use_effect`, `use_state`, `use_reducer`, `use_memo`, `use_callback`, `use_id`, `use_transition`, `use_debug_value`, `use_ref`, and `use_context` hooks from React as well as a `use_url` hook for simple routing.\n\n## Routing\n\n`react_gleam/router` provides a `use_url` hook, `push`, and `back` function to enable basic routing.\n\n```gleam\nimport react_gleam.{component, render}\nimport react_gleam/element.{div, text}\nimport react_gleam/router.{use_url}\n\npub fn main() {\n  render(app(), &quot;#app&quot;)\n}\n\nfn app() {\n  use &lt;- component()\n\n  let url = use_url()\n\n  case url.path {\n    [] -&gt; div([], [text(&quot;home&quot;)]) // Matches /\n    [&quot;about&quot;] -&gt; div([], [text(&quot;about&quot;)]) // Matches /about\n    _ -&gt; div([], [text(&quot;404&quot;)]) // Matches everything else\n  }\n}\n\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add react_gleam\n\nyarn add react react-dom\n```\n","url":"index.html"},{"doc":"react_gleam/dom_element","title":"DomElement","content":"pub external type DomElement\n\n\nSynonyms:\nreact_gleam/dom_element.DomElement\nreact_gleam/dom_element DomElement","url":"react_gleam/dom_element.html#DomElement"},{"doc":"react_gleam/dom_element","title":"get_attribute","content":"pub external fn get_attribute(\n  element: DomElement,\n  name: String,\n) -&gt; Option(String)\n\nSynonyms:\nreact_gleam/dom_element.get_attribute\nreact_gleam/dom_element get_attribute","url":"react_gleam/dom_element.html#get_attribute"},{"doc":"react_gleam/dom_element","title":"set_attribute","content":"pub external fn set_attribute(\n  element: DomElement,\n  name: String,\n  value: String,\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/dom_element.set_attribute\nreact_gleam/dom_element set_attribute","url":"react_gleam/dom_element.html#set_attribute"},{"doc":"react_gleam/dom_element","title":"react_gleam/dom_element","content":"","url":"react_gleam/dom_element.html"},{"doc":"react_gleam/hook","title":"Ref","content":"pub type Ref(g) {\n  Ref(current: Option(g))\n}\n\nRef(current: Option(g))\n\n\nSynonyms:\nreact_gleam/hook.Ref\nreact_gleam/hook Ref","url":"react_gleam/hook.html#Ref"},{"doc":"react_gleam/hook","title":"use_callback1","content":"pub external fn use_callback1(\n  callback: fn() -&gt; fn() -&gt; v,\n  dependencies: #(g),\n) -&gt; v\n\nSynonyms:\nreact_gleam/hook.use_callback1\nreact_gleam/hook use_callback1","url":"react_gleam/hook.html#use_callback1"},{"doc":"react_gleam/hook","title":"use_callback2","content":"pub external fn use_callback2(\n  callback: fn() -&gt; fn() -&gt; v,\n  dependencies: #(g, l),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_callback2\nreact_gleam/hook use_callback2","url":"react_gleam/hook.html#use_callback2"},{"doc":"react_gleam/hook","title":"use_callback3","content":"pub external fn use_callback3(\n  callback: fn() -&gt; fn() -&gt; v,\n  dependencies: #(g, l, e),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_callback3\nreact_gleam/hook use_callback3","url":"react_gleam/hook.html#use_callback3"},{"doc":"react_gleam/hook","title":"use_callback4","content":"pub external fn use_callback4(\n  callback: fn() -&gt; fn() -&gt; v,\n  dependencies: #(g, l, e, a),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_callback4\nreact_gleam/hook use_callback4","url":"react_gleam/hook.html#use_callback4"},{"doc":"react_gleam/hook","title":"use_callback5","content":"pub external fn use_callback5(\n  callback: fn() -&gt; fn() -&gt; v,\n  dependencies: #(g, l, e, a, m),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_callback5\nreact_gleam/hook use_callback5","url":"react_gleam/hook.html#use_callback5"},{"doc":"react_gleam/hook","title":"use_callback6","content":"pub external fn use_callback6(\n  callback: fn() -&gt; fn() -&gt; v,\n  dependencies: #(g, l, e, a, m, o),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_callback6\nreact_gleam/hook use_callback6","url":"react_gleam/hook.html#use_callback6"},{"doc":"react_gleam/hook","title":"use_callback7","content":"pub external fn use_callback7(\n  callback: fn() -&gt; fn() -&gt; v,\n  dependencies: #(g, l, e, a, m, o, r),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_callback7\nreact_gleam/hook use_callback7","url":"react_gleam/hook.html#use_callback7"},{"doc":"react_gleam/hook","title":"use_context","content":"pub external fn use_context(\n  key: String,\n) -&gt; Result(Dynamic, String)\n\nSynonyms:\nreact_gleam/hook.use_context\nreact_gleam/hook use_context","url":"react_gleam/hook.html#use_context"},{"doc":"react_gleam/hook","title":"use_debug_value","content":"pub external fn use_debug_value(value: String) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_debug_value\nreact_gleam/hook use_debug_value","url":"react_gleam/hook.html#use_debug_value"},{"doc":"react_gleam/hook","title":"use_effect","content":"pub external fn use_effect(\n  callback: fn() -&gt; Option(fn() -&gt; Nil),\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_effect\nreact_gleam/hook use_effect","url":"react_gleam/hook.html#use_effect"},{"doc":"react_gleam/hook","title":"use_effect0","content":"pub external fn use_effect0(\n  callback: fn() -&gt; Option(fn() -&gt; Nil),\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_effect0\nreact_gleam/hook use_effect0","url":"react_gleam/hook.html#use_effect0"},{"doc":"react_gleam/hook","title":"use_effect1","content":"pub external fn use_effect1(\n  callback: fn() -&gt; Option(fn() -&gt; Nil),\n  dependencies: #(g),\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_effect1\nreact_gleam/hook use_effect1","url":"react_gleam/hook.html#use_effect1"},{"doc":"react_gleam/hook","title":"use_effect2","content":"pub external fn use_effect2(\n  callback: fn() -&gt; Option(fn() -&gt; Nil),\n  dependencies: #(g, l),\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_effect2\nreact_gleam/hook use_effect2","url":"react_gleam/hook.html#use_effect2"},{"doc":"react_gleam/hook","title":"use_effect3","content":"pub external fn use_effect3(\n  callback: fn() -&gt; Option(fn() -&gt; Nil),\n  dependencies: #(g, l, e),\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_effect3\nreact_gleam/hook use_effect3","url":"react_gleam/hook.html#use_effect3"},{"doc":"react_gleam/hook","title":"use_effect4","content":"pub external fn use_effect4(\n  callback: fn() -&gt; Option(fn() -&gt; Nil),\n  dependencies: #(g, l, e, a),\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_effect4\nreact_gleam/hook use_effect4","url":"react_gleam/hook.html#use_effect4"},{"doc":"react_gleam/hook","title":"use_effect5","content":"pub external fn use_effect5(\n  callback: fn() -&gt; Option(fn() -&gt; Nil),\n  dependencies: #(g, l, e, a, m),\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_effect5\nreact_gleam/hook use_effect5","url":"react_gleam/hook.html#use_effect5"},{"doc":"react_gleam/hook","title":"use_effect6","content":"pub external fn use_effect6(\n  callback: fn() -&gt; Option(fn() -&gt; Nil),\n  dependencies: #(g, l, e, a, m, o),\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_effect6\nreact_gleam/hook use_effect6","url":"react_gleam/hook.html#use_effect6"},{"doc":"react_gleam/hook","title":"use_effect7","content":"pub external fn use_effect7(\n  callback: fn() -&gt; Option(fn() -&gt; Nil),\n  dependencies: #(g, l, e, a, m, o, r),\n) -&gt; Nil\n\nSynonyms:\nreact_gleam/hook.use_effect7\nreact_gleam/hook use_effect7","url":"react_gleam/hook.html#use_effect7"},{"doc":"react_gleam/hook","title":"use_id","content":"pub external fn use_id() -&gt; String\n\nSynonyms:\nreact_gleam/hook.use_id\nreact_gleam/hook use_id","url":"react_gleam/hook.html#use_id"},{"doc":"react_gleam/hook","title":"use_memo1","content":"pub external fn use_memo1(\n  calculation: fn() -&gt; v,\n  dependencies: #(g),\n) -&gt; v\n\nSynonyms:\nreact_gleam/hook.use_memo1\nreact_gleam/hook use_memo1","url":"react_gleam/hook.html#use_memo1"},{"doc":"react_gleam/hook","title":"use_memo2","content":"pub external fn use_memo2(\n  calculation: fn() -&gt; v,\n  dependencies: #(g, l),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_memo2\nreact_gleam/hook use_memo2","url":"react_gleam/hook.html#use_memo2"},{"doc":"react_gleam/hook","title":"use_memo3","content":"pub external fn use_memo3(\n  calculation: fn() -&gt; v,\n  dependencies: #(g, l, e),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_memo3\nreact_gleam/hook use_memo3","url":"react_gleam/hook.html#use_memo3"},{"doc":"react_gleam/hook","title":"use_memo4","content":"pub external fn use_memo4(\n  calculation: fn() -&gt; v,\n  dependencies: #(g, l, e, a),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_memo4\nreact_gleam/hook use_memo4","url":"react_gleam/hook.html#use_memo4"},{"doc":"react_gleam/hook","title":"use_memo5","content":"pub external fn use_memo5(\n  calculation: fn() -&gt; v,\n  dependencies: #(g, l, e, a, m),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_memo5\nreact_gleam/hook use_memo5","url":"react_gleam/hook.html#use_memo5"},{"doc":"react_gleam/hook","title":"use_memo6","content":"pub external fn use_memo6(\n  calculation: fn() -&gt; v,\n  dependencies: #(g, l, e, a, m, o),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_memo6\nreact_gleam/hook use_memo6","url":"react_gleam/hook.html#use_memo6"},{"doc":"react_gleam/hook","title":"use_memo7","content":"pub external fn use_memo7(\n  calculation: fn() -&gt; v,\n  dependencies: #(g, l, e, a, m, o, r),\n) -&gt; g\n\nSynonyms:\nreact_gleam/hook.use_memo7\nreact_gleam/hook use_memo7","url":"react_gleam/hook.html#use_memo7"},{"doc":"react_gleam/hook","title":"use_reducer","content":"pub external fn use_reducer(\n  reducer: fn(a, b) -&gt; a,\n  initial: a,\n) -&gt; #(a, fn(b) -&gt; Nil)\n\nSynonyms:\nreact_gleam/hook.use_reducer\nreact_gleam/hook use_reducer","url":"react_gleam/hook.html#use_reducer"},{"doc":"react_gleam/hook","title":"use_ref","content":"pub external fn use_ref(\n  value: Option(DomElement),\n) -&gt; Ref(DomElement)\n\nSynonyms:\nreact_gleam/hook.use_ref\nreact_gleam/hook use_ref","url":"react_gleam/hook.html#use_ref"},{"doc":"react_gleam/hook","title":"use_state","content":"pub external fn use_state(\n  initial: fn(a) -&gt; a,\n) -&gt; #(a, fn(fn(a) -&gt; a) -&gt; Nil)\n\nSynonyms:\nreact_gleam/hook.use_state\nreact_gleam/hook use_state","url":"react_gleam/hook.html#use_state"},{"doc":"react_gleam/hook","title":"use_transition","content":"pub external fn use_transition(\n  cb: fn() -&gt; Nil,\n) -&gt; #(Bool, fn() -&gt; Nil)\n\nSynonyms:\nreact_gleam/hook.use_transition\nreact_gleam/hook use_transition","url":"react_gleam/hook.html#use_transition"},{"doc":"react_gleam/hook","title":"react_gleam/hook","content":"","url":"react_gleam/hook.html"},{"doc":"react_gleam/attribute","title":"Attribute","content":"pub opaque type Attribute(g, action)\n\n\nSynonyms:\nreact_gleam/attribute.Attribute\nreact_gleam/attribute Attribute","url":"react_gleam/attribute.html#Attribute"},{"doc":"react_gleam/attribute","title":"accept","content":"pub fn accept(types: List(String)) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.accept\nreact_gleam/attribute accept","url":"react_gleam/attribute.html#accept"},{"doc":"react_gleam/attribute","title":"accept_charset","content":"pub fn accept_charset(types: List(String)) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.accept_charset\nreact_gleam/attribute accept_charset","url":"react_gleam/attribute.html#accept_charset"},{"doc":"react_gleam/attribute","title":"action","content":"pub fn action(uri: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.action\nreact_gleam/attribute action","url":"react_gleam/attribute.html#action"},{"doc":"react_gleam/attribute","title":"alt","content":"pub fn alt(text: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.alt\nreact_gleam/attribute alt","url":"react_gleam/attribute.html#alt"},{"doc":"react_gleam/attribute","title":"attribute","content":"pub fn attribute(name: String, value: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.attribute\nreact_gleam/attribute attribute","url":"react_gleam/attribute.html#attribute"},{"doc":"react_gleam/attribute","title":"autocomplete","content":"pub fn autocomplete(should_autocomplete: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.autocomplete\nreact_gleam/attribute autocomplete","url":"react_gleam/attribute.html#autocomplete"},{"doc":"react_gleam/attribute","title":"autofocus","content":"pub fn autofocus(should_autofocus: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.autofocus\nreact_gleam/attribute autofocus","url":"react_gleam/attribute.html#autofocus"},{"doc":"react_gleam/attribute","title":"autoplay","content":"pub fn autoplay(should_autoplay: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.autoplay\nreact_gleam/attribute autoplay","url":"react_gleam/attribute.html#autoplay"},{"doc":"react_gleam/attribute","title":"checked","content":"pub fn checked(is_checked: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.checked\nreact_gleam/attribute checked","url":"react_gleam/attribute.html#checked"},{"doc":"react_gleam/attribute","title":"class","content":"pub fn class(name: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.class\nreact_gleam/attribute class","url":"react_gleam/attribute.html#class"},{"doc":"react_gleam/attribute","title":"classes","content":"pub fn classes(names: List(#(String, Bool))) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.classes\nreact_gleam/attribute classes","url":"react_gleam/attribute.html#classes"},{"doc":"react_gleam/attribute","title":"cols","content":"pub fn cols(val: Int) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.cols\nreact_gleam/attribute cols","url":"react_gleam/attribute.html#cols"},{"doc":"react_gleam/attribute","title":"controls","content":"pub fn controls(visible: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.controls\nreact_gleam/attribute controls","url":"react_gleam/attribute.html#controls"},{"doc":"react_gleam/attribute","title":"disabled","content":"pub fn disabled(is_disabled: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.disabled\nreact_gleam/attribute disabled","url":"react_gleam/attribute.html#disabled"},{"doc":"react_gleam/attribute","title":"download","content":"pub fn download(filename: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.download\nreact_gleam/attribute download","url":"react_gleam/attribute.html#download"},{"doc":"react_gleam/attribute","title":"event","content":"pub fn event(name: String, handler: fn(Dynamic, fn(a) -&gt; Nil) -&gt;\n    Nil) -&gt; Attribute(b, a)\n\nSynonyms:\nreact_gleam/attribute.event\nreact_gleam/attribute event","url":"react_gleam/attribute.html#event"},{"doc":"react_gleam/attribute","title":"for","content":"pub fn for(id: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.for\nreact_gleam/attribute for","url":"react_gleam/attribute.html#for"},{"doc":"react_gleam/attribute","title":"height","content":"pub fn height(val: Int) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.height\nreact_gleam/attribute height","url":"react_gleam/attribute.html#height"},{"doc":"react_gleam/attribute","title":"href","content":"pub fn href(uri: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.href\nreact_gleam/attribute href","url":"react_gleam/attribute.html#href"},{"doc":"react_gleam/attribute","title":"id","content":"pub fn id(name: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.id\nreact_gleam/attribute id","url":"react_gleam/attribute.html#id"},{"doc":"react_gleam/attribute","title":"loop","content":"pub fn loop(should_loop: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.loop\nreact_gleam/attribute loop","url":"react_gleam/attribute.html#loop"},{"doc":"react_gleam/attribute","title":"max","content":"pub fn max(val: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.max\nreact_gleam/attribute max","url":"react_gleam/attribute.html#max"},{"doc":"react_gleam/attribute","title":"min","content":"pub fn min(val: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.min\nreact_gleam/attribute min","url":"react_gleam/attribute.html#min"},{"doc":"react_gleam/attribute","title":"name","content":"pub fn name(name: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.name\nreact_gleam/attribute name","url":"react_gleam/attribute.html#name"},{"doc":"react_gleam/attribute","title":"pattern","content":"pub fn pattern(regex: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.pattern\nreact_gleam/attribute pattern","url":"react_gleam/attribute.html#pattern"},{"doc":"react_gleam/attribute","title":"placeholder","content":"pub fn placeholder(text: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.placeholder\nreact_gleam/attribute placeholder","url":"react_gleam/attribute.html#placeholder"},{"doc":"react_gleam/attribute","title":"property","content":"pub fn property(name: String, value: Dynamic) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.property\nreact_gleam/attribute property","url":"react_gleam/attribute.html#property"},{"doc":"react_gleam/attribute","title":"readonly","content":"pub fn readonly(is_readonly: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.readonly\nreact_gleam/attribute readonly","url":"react_gleam/attribute.html#readonly"},{"doc":"react_gleam/attribute","title":"ref","content":"pub fn ref(value: Ref(a)) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.ref\nreact_gleam/attribute ref","url":"react_gleam/attribute.html#ref"},{"doc":"react_gleam/attribute","title":"rel","content":"pub fn rel(relationship: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.rel\nreact_gleam/attribute rel","url":"react_gleam/attribute.html#rel"},{"doc":"react_gleam/attribute","title":"required","content":"pub fn required(is_required: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.required\nreact_gleam/attribute required","url":"react_gleam/attribute.html#required"},{"doc":"react_gleam/attribute","title":"rows","content":"pub fn rows(val: Int) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.rows\nreact_gleam/attribute rows","url":"react_gleam/attribute.html#rows"},{"doc":"react_gleam/attribute","title":"selected","content":"pub fn selected(is_selected: Bool) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.selected\nreact_gleam/attribute selected","url":"react_gleam/attribute.html#selected"},{"doc":"react_gleam/attribute","title":"src","content":"pub fn src(uri: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.src\nreact_gleam/attribute src","url":"react_gleam/attribute.html#src"},{"doc":"react_gleam/attribute","title":"step","content":"pub fn step(val: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.step\nreact_gleam/attribute step","url":"react_gleam/attribute.html#step"},{"doc":"react_gleam/attribute","title":"style","content":"pub fn style(properties: List(#(String, String))) -&gt; Attribute(\n  a,\n  b,\n)\n\nSynonyms:\nreact_gleam/attribute.style\nreact_gleam/attribute style","url":"react_gleam/attribute.html#style"},{"doc":"react_gleam/attribute","title":"target","content":"pub fn target(target: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.target\nreact_gleam/attribute target","url":"react_gleam/attribute.html#target"},{"doc":"react_gleam/attribute","title":"type_","content":"pub fn type_(name: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.type_\nreact_gleam/attribute type_","url":"react_gleam/attribute.html#type_"},{"doc":"react_gleam/attribute","title":"value","content":"pub fn value(val: Dynamic) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.value\nreact_gleam/attribute value","url":"react_gleam/attribute.html#value"},{"doc":"react_gleam/attribute","title":"width","content":"pub fn width(val: Int) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.width\nreact_gleam/attribute width","url":"react_gleam/attribute.html#width"},{"doc":"react_gleam/attribute","title":"wrap","content":"pub fn wrap(mode: String) -&gt; Attribute(a, b)\n\nSynonyms:\nreact_gleam/attribute.wrap\nreact_gleam/attribute wrap","url":"react_gleam/attribute.html#wrap"},{"doc":"react_gleam/attribute","title":"react_gleam/attribute","content":"","url":"react_gleam/attribute.html"},{"doc":"react_gleam/event","title":"dispatch","content":"pub fn dispatch(action: a) -&gt; fn(fn(a) -&gt; Nil) -&gt; Nil\n\nSynonyms:\nreact_gleam/event.dispatch\nreact_gleam/event dispatch","url":"react_gleam/event.html#dispatch"},{"doc":"react_gleam/event","title":"on","content":"pub fn on(name: String, handler: fn(Dynamic, fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on\nreact_gleam/event on","url":"react_gleam/event.html#on"},{"doc":"react_gleam/event","title":"on_blur","content":"pub fn on_blur(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_blur\nreact_gleam/event on_blur","url":"react_gleam/event.html#on_blur"},{"doc":"react_gleam/event","title":"on_check","content":"pub fn on_check(handler: fn(Bool, fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_check\nreact_gleam/event on_check","url":"react_gleam/event.html#on_check"},{"doc":"react_gleam/event","title":"on_click","content":"pub fn on_click(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_click\nreact_gleam/event on_click","url":"react_gleam/event.html#on_click"},{"doc":"react_gleam/event","title":"on_focus","content":"pub fn on_focus(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_focus\nreact_gleam/event on_focus","url":"react_gleam/event.html#on_focus"},{"doc":"react_gleam/event","title":"on_input","content":"pub fn on_input(handler: fn(String, fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_input\nreact_gleam/event on_input","url":"react_gleam/event.html#on_input"},{"doc":"react_gleam/event","title":"on_keydown","content":"pub fn on_keydown(handler: fn(String, fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_keydown\nreact_gleam/event on_keydown","url":"react_gleam/event.html#on_keydown"},{"doc":"react_gleam/event","title":"on_keypress","content":"pub fn on_keypress(handler: fn(String, fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_keypress\nreact_gleam/event on_keypress","url":"react_gleam/event.html#on_keypress"},{"doc":"react_gleam/event","title":"on_keyup","content":"pub fn on_keyup(handler: fn(String, fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_keyup\nreact_gleam/event on_keyup","url":"react_gleam/event.html#on_keyup"},{"doc":"react_gleam/event","title":"on_mouse_down","content":"pub fn on_mouse_down(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_mouse_down\nreact_gleam/event on_mouse_down","url":"react_gleam/event.html#on_mouse_down"},{"doc":"react_gleam/event","title":"on_mouse_enter","content":"pub fn on_mouse_enter(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_mouse_enter\nreact_gleam/event on_mouse_enter","url":"react_gleam/event.html#on_mouse_enter"},{"doc":"react_gleam/event","title":"on_mouse_leave","content":"pub fn on_mouse_leave(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_mouse_leave\nreact_gleam/event on_mouse_leave","url":"react_gleam/event.html#on_mouse_leave"},{"doc":"react_gleam/event","title":"on_mouse_out","content":"pub fn on_mouse_out(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_mouse_out\nreact_gleam/event on_mouse_out","url":"react_gleam/event.html#on_mouse_out"},{"doc":"react_gleam/event","title":"on_mouse_over","content":"pub fn on_mouse_over(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_mouse_over\nreact_gleam/event on_mouse_over","url":"react_gleam/event.html#on_mouse_over"},{"doc":"react_gleam/event","title":"on_mouse_up","content":"pub fn on_mouse_up(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_mouse_up\nreact_gleam/event on_mouse_up","url":"react_gleam/event.html#on_mouse_up"},{"doc":"react_gleam/event","title":"on_submit","content":"pub fn on_submit(handler: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Attribute(\n  b,\n  a,\n)\n\nSynonyms:\nreact_gleam/event.on_submit\nreact_gleam/event on_submit","url":"react_gleam/event.html#on_submit"},{"doc":"react_gleam/event","title":"react_gleam/event","content":"","url":"react_gleam/event.html"},{"doc":"react_gleam/router","title":"Location","content":"pub type Location {\n  Location(path: List(String), hash: String, search: String)\n}\n\nLocation(path: List(String), hash: String, search: String)\n\n\nSynonyms:\nreact_gleam/router.Location\nreact_gleam/router Location","url":"react_gleam/router.html#Location"},{"doc":"react_gleam/router","title":"back","content":"pub external fn back() -&gt; Nil\n\nSynonyms:\nreact_gleam/router.back\nreact_gleam/router back","url":"react_gleam/router.html#back"},{"doc":"react_gleam/router","title":"push","content":"pub external fn push(url: String) -&gt; Nil\n\nSynonyms:\nreact_gleam/router.push\nreact_gleam/router push","url":"react_gleam/router.html#push"},{"doc":"react_gleam/router","title":"use_url","content":"pub fn use_url() -&gt; Location\n\nSynonyms:\nreact_gleam/router.use_url\nreact_gleam/router use_url","url":"react_gleam/router.html#use_url"},{"doc":"react_gleam/router","title":"react_gleam/router","content":"","url":"react_gleam/router.html"},{"doc":"react_gleam/element","title":"Element","content":"pub external type Element\n\n\nSynonyms:\nreact_gleam/element.Element\nreact_gleam/element Element","url":"react_gleam/element.html#Element"},{"doc":"react_gleam/element","title":"a","content":"pub fn a(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.a\nreact_gleam/element a","url":"react_gleam/element.html#a"},{"doc":"react_gleam/element","title":"abbr","content":"pub fn abbr(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.abbr\nreact_gleam/element abbr","url":"react_gleam/element.html#abbr"},{"doc":"react_gleam/element","title":"address","content":"pub fn address(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.address\nreact_gleam/element address","url":"react_gleam/element.html#address"},{"doc":"react_gleam/element","title":"area","content":"pub fn area(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.area\nreact_gleam/element area","url":"react_gleam/element.html#area"},{"doc":"react_gleam/element","title":"article","content":"pub fn article(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.article\nreact_gleam/element article","url":"react_gleam/element.html#article"},{"doc":"react_gleam/element","title":"aside","content":"pub fn aside(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.aside\nreact_gleam/element aside","url":"react_gleam/element.html#aside"},{"doc":"react_gleam/element","title":"audio","content":"pub fn audio(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.audio\nreact_gleam/element audio","url":"react_gleam/element.html#audio"},{"doc":"react_gleam/element","title":"b","content":"pub fn b(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.b\nreact_gleam/element b","url":"react_gleam/element.html#b"},{"doc":"react_gleam/element","title":"base","content":"pub fn base(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.base\nreact_gleam/element base","url":"react_gleam/element.html#base"},{"doc":"react_gleam/element","title":"bdi","content":"pub fn bdi(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.bdi\nreact_gleam/element bdi","url":"react_gleam/element.html#bdi"},{"doc":"react_gleam/element","title":"bdo","content":"pub fn bdo(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.bdo\nreact_gleam/element bdo","url":"react_gleam/element.html#bdo"},{"doc":"react_gleam/element","title":"blockquote","content":"pub fn blockquote(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.blockquote\nreact_gleam/element blockquote","url":"react_gleam/element.html#blockquote"},{"doc":"react_gleam/element","title":"body","content":"pub fn body(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.body\nreact_gleam/element body","url":"react_gleam/element.html#body"},{"doc":"react_gleam/element","title":"br","content":"pub fn br(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.br\nreact_gleam/element br","url":"react_gleam/element.html#br"},{"doc":"react_gleam/element","title":"button","content":"pub fn button(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.button\nreact_gleam/element button","url":"react_gleam/element.html#button"},{"doc":"react_gleam/element","title":"canvas","content":"pub fn canvas(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.canvas\nreact_gleam/element canvas","url":"react_gleam/element.html#canvas"},{"doc":"react_gleam/element","title":"caption","content":"pub fn caption(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.caption\nreact_gleam/element caption","url":"react_gleam/element.html#caption"},{"doc":"react_gleam/element","title":"cite","content":"pub fn cite(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.cite\nreact_gleam/element cite","url":"react_gleam/element.html#cite"},{"doc":"react_gleam/element","title":"code","content":"pub fn code(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.code\nreact_gleam/element code","url":"react_gleam/element.html#code"},{"doc":"react_gleam/element","title":"col","content":"pub fn col(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.col\nreact_gleam/element col","url":"react_gleam/element.html#col"},{"doc":"react_gleam/element","title":"colgroup","content":"pub fn colgroup(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.colgroup\nreact_gleam/element colgroup","url":"react_gleam/element.html#colgroup"},{"doc":"react_gleam/element","title":"datalist","content":"pub fn datalist(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.datalist\nreact_gleam/element datalist","url":"react_gleam/element.html#datalist"},{"doc":"react_gleam/element","title":"dd","content":"pub fn dd(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.dd\nreact_gleam/element dd","url":"react_gleam/element.html#dd"},{"doc":"react_gleam/element","title":"del","content":"pub fn del(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.del\nreact_gleam/element del","url":"react_gleam/element.html#del"},{"doc":"react_gleam/element","title":"details","content":"pub fn details(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.details\nreact_gleam/element details","url":"react_gleam/element.html#details"},{"doc":"react_gleam/element","title":"dfn","content":"pub fn dfn(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.dfn\nreact_gleam/element dfn","url":"react_gleam/element.html#dfn"},{"doc":"react_gleam/element","title":"dialog","content":"pub fn dialog(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.dialog\nreact_gleam/element dialog","url":"react_gleam/element.html#dialog"},{"doc":"react_gleam/element","title":"div","content":"pub fn div(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.div\nreact_gleam/element div","url":"react_gleam/element.html#div"},{"doc":"react_gleam/element","title":"dl","content":"pub fn dl(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.dl\nreact_gleam/element dl","url":"react_gleam/element.html#dl"},{"doc":"react_gleam/element","title":"dt","content":"pub fn dt(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.dt\nreact_gleam/element dt","url":"react_gleam/element.html#dt"},{"doc":"react_gleam/element","title":"em","content":"pub fn em(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.em\nreact_gleam/element em","url":"react_gleam/element.html#em"},{"doc":"react_gleam/element","title":"embed","content":"pub fn embed(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.embed\nreact_gleam/element embed","url":"react_gleam/element.html#embed"},{"doc":"react_gleam/element","title":"fieldset","content":"pub fn fieldset(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.fieldset\nreact_gleam/element fieldset","url":"react_gleam/element.html#fieldset"},{"doc":"react_gleam/element","title":"figcaption","content":"pub fn figcaption(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.figcaption\nreact_gleam/element figcaption","url":"react_gleam/element.html#figcaption"},{"doc":"react_gleam/element","title":"figure","content":"pub fn figure(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.figure\nreact_gleam/element figure","url":"react_gleam/element.html#figure"},{"doc":"react_gleam/element","title":"footer","content":"pub fn footer(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.footer\nreact_gleam/element footer","url":"react_gleam/element.html#footer"},{"doc":"react_gleam/element","title":"form","content":"pub fn form(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.form\nreact_gleam/element form","url":"react_gleam/element.html#form"},{"doc":"react_gleam/element","title":"h1","content":"pub fn h1(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.h1\nreact_gleam/element h1","url":"react_gleam/element.html#h1"},{"doc":"react_gleam/element","title":"h2","content":"pub fn h2(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.h2\nreact_gleam/element h2","url":"react_gleam/element.html#h2"},{"doc":"react_gleam/element","title":"h3","content":"pub fn h3(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.h3\nreact_gleam/element h3","url":"react_gleam/element.html#h3"},{"doc":"react_gleam/element","title":"h4","content":"pub fn h4(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.h4\nreact_gleam/element h4","url":"react_gleam/element.html#h4"},{"doc":"react_gleam/element","title":"h5","content":"pub fn h5(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.h5\nreact_gleam/element h5","url":"react_gleam/element.html#h5"},{"doc":"react_gleam/element","title":"h6","content":"pub fn h6(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.h6\nreact_gleam/element h6","url":"react_gleam/element.html#h6"},{"doc":"react_gleam/element","title":"head","content":"pub fn head(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.head\nreact_gleam/element head","url":"react_gleam/element.html#head"},{"doc":"react_gleam/element","title":"header","content":"pub fn header(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.header\nreact_gleam/element header","url":"react_gleam/element.html#header"},{"doc":"react_gleam/element","title":"hr","content":"pub fn hr(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.hr\nreact_gleam/element hr","url":"react_gleam/element.html#hr"},{"doc":"react_gleam/element","title":"html","content":"pub fn html(attributes: List(Attribute(a, b)), head: Element, body: Element) -&gt; Element\n\nSynonyms:\nreact_gleam/element.html\nreact_gleam/element html","url":"react_gleam/element.html#html"},{"doc":"react_gleam/element","title":"i","content":"pub fn i(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.i\nreact_gleam/element i","url":"react_gleam/element.html#i"},{"doc":"react_gleam/element","title":"iframe","content":"pub fn iframe(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.iframe\nreact_gleam/element iframe","url":"react_gleam/element.html#iframe"},{"doc":"react_gleam/element","title":"img","content":"pub fn img(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.img\nreact_gleam/element img","url":"react_gleam/element.html#img"},{"doc":"react_gleam/element","title":"input","content":"pub fn input(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.input\nreact_gleam/element input","url":"react_gleam/element.html#input"},{"doc":"react_gleam/element","title":"ins","content":"pub fn ins(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.ins\nreact_gleam/element ins","url":"react_gleam/element.html#ins"},{"doc":"react_gleam/element","title":"kbd","content":"pub fn kbd(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.kbd\nreact_gleam/element kbd","url":"react_gleam/element.html#kbd"},{"doc":"react_gleam/element","title":"label","content":"pub fn label(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.label\nreact_gleam/element label","url":"react_gleam/element.html#label"},{"doc":"react_gleam/element","title":"legend","content":"pub fn legend(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.legend\nreact_gleam/element legend","url":"react_gleam/element.html#legend"},{"doc":"react_gleam/element","title":"li","content":"pub fn li(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.li\nreact_gleam/element li","url":"react_gleam/element.html#li"},{"doc":"react_gleam/element","title":"main","content":"pub fn main(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.main\nreact_gleam/element main","url":"react_gleam/element.html#main"},{"doc":"react_gleam/element","title":"map_","content":"pub fn map_(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.map_\nreact_gleam/element map_","url":"react_gleam/element.html#map_"},{"doc":"react_gleam/element","title":"mark","content":"pub fn mark(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.mark\nreact_gleam/element mark","url":"react_gleam/element.html#mark"},{"doc":"react_gleam/element","title":"mathml","content":"pub fn mathml(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.mathml\nreact_gleam/element mathml","url":"react_gleam/element.html#mathml"},{"doc":"react_gleam/element","title":"menu","content":"pub fn menu(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.menu\nreact_gleam/element menu","url":"react_gleam/element.html#menu"},{"doc":"react_gleam/element","title":"meta","content":"pub fn meta(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.meta\nreact_gleam/element meta","url":"react_gleam/element.html#meta"},{"doc":"react_gleam/element","title":"meter","content":"pub fn meter(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.meter\nreact_gleam/element meter","url":"react_gleam/element.html#meter"},{"doc":"react_gleam/element","title":"nav","content":"pub fn nav(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.nav\nreact_gleam/element nav","url":"react_gleam/element.html#nav"},{"doc":"react_gleam/element","title":"node","content":"pub external fn node(\n  tag: String,\n  attributes: List(Attribute(g, action)),\n  children: List(Element),\n) -&gt; Element\n\nSynonyms:\nreact_gleam/element.node\nreact_gleam/element node","url":"react_gleam/element.html#node"},{"doc":"react_gleam/element","title":"noscript","content":"pub fn noscript(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.noscript\nreact_gleam/element noscript","url":"react_gleam/element.html#noscript"},{"doc":"react_gleam/element","title":"object","content":"pub fn object(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.object\nreact_gleam/element object","url":"react_gleam/element.html#object"},{"doc":"react_gleam/element","title":"ol","content":"pub fn ol(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.ol\nreact_gleam/element ol","url":"react_gleam/element.html#ol"},{"doc":"react_gleam/element","title":"optgroup","content":"pub fn optgroup(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.optgroup\nreact_gleam/element optgroup","url":"react_gleam/element.html#optgroup"},{"doc":"react_gleam/element","title":"option","content":"pub fn option(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.option\nreact_gleam/element option","url":"react_gleam/element.html#option"},{"doc":"react_gleam/element","title":"output","content":"pub fn output(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.output\nreact_gleam/element output","url":"react_gleam/element.html#output"},{"doc":"react_gleam/element","title":"p","content":"pub fn p(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.p\nreact_gleam/element p","url":"react_gleam/element.html#p"},{"doc":"react_gleam/element","title":"param","content":"pub fn param(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.param\nreact_gleam/element param","url":"react_gleam/element.html#param"},{"doc":"react_gleam/element","title":"picture","content":"pub fn picture(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.picture\nreact_gleam/element picture","url":"react_gleam/element.html#picture"},{"doc":"react_gleam/element","title":"portal","content":"pub fn portal(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.portal\nreact_gleam/element portal","url":"react_gleam/element.html#portal"},{"doc":"react_gleam/element","title":"pre","content":"pub fn pre(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.pre\nreact_gleam/element pre","url":"react_gleam/element.html#pre"},{"doc":"react_gleam/element","title":"progress","content":"pub fn progress(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.progress\nreact_gleam/element progress","url":"react_gleam/element.html#progress"},{"doc":"react_gleam/element","title":"rp","content":"pub fn rp(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.rp\nreact_gleam/element rp","url":"react_gleam/element.html#rp"},{"doc":"react_gleam/element","title":"rt","content":"pub fn rt(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.rt\nreact_gleam/element rt","url":"react_gleam/element.html#rt"},{"doc":"react_gleam/element","title":"ruby","content":"pub fn ruby(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.ruby\nreact_gleam/element ruby","url":"react_gleam/element.html#ruby"},{"doc":"react_gleam/element","title":"s","content":"pub fn s(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.s\nreact_gleam/element s","url":"react_gleam/element.html#s"},{"doc":"react_gleam/element","title":"samp","content":"pub fn samp(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.samp\nreact_gleam/element samp","url":"react_gleam/element.html#samp"},{"doc":"react_gleam/element","title":"section","content":"pub fn section(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.section\nreact_gleam/element section","url":"react_gleam/element.html#section"},{"doc":"react_gleam/element","title":"select","content":"pub fn select(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.select\nreact_gleam/element select","url":"react_gleam/element.html#select"},{"doc":"react_gleam/element","title":"slot","content":"pub fn slot(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.slot\nreact_gleam/element slot","url":"react_gleam/element.html#slot"},{"doc":"react_gleam/element","title":"small","content":"pub fn small(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.small\nreact_gleam/element small","url":"react_gleam/element.html#small"},{"doc":"react_gleam/element","title":"source","content":"pub fn source(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.source\nreact_gleam/element source","url":"react_gleam/element.html#source"},{"doc":"react_gleam/element","title":"span","content":"pub fn span(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.span\nreact_gleam/element span","url":"react_gleam/element.html#span"},{"doc":"react_gleam/element","title":"strong","content":"pub fn strong(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.strong\nreact_gleam/element strong","url":"react_gleam/element.html#strong"},{"doc":"react_gleam/element","title":"style","content":"pub fn style(attributes: List(Attribute(a, b)), css: String) -&gt; Element\n\nSynonyms:\nreact_gleam/element.style\nreact_gleam/element style","url":"react_gleam/element.html#style"},{"doc":"react_gleam/element","title":"sub","content":"pub fn sub(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.sub\nreact_gleam/element sub","url":"react_gleam/element.html#sub"},{"doc":"react_gleam/element","title":"summary","content":"pub fn summary(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.summary\nreact_gleam/element summary","url":"react_gleam/element.html#summary"},{"doc":"react_gleam/element","title":"sup","content":"pub fn sup(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.sup\nreact_gleam/element sup","url":"react_gleam/element.html#sup"},{"doc":"react_gleam/element","title":"svg","content":"pub fn svg(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.svg\nreact_gleam/element svg","url":"react_gleam/element.html#svg"},{"doc":"react_gleam/element","title":"table","content":"pub fn table(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.table\nreact_gleam/element table","url":"react_gleam/element.html#table"},{"doc":"react_gleam/element","title":"tbody","content":"pub fn tbody(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.tbody\nreact_gleam/element tbody","url":"react_gleam/element.html#tbody"},{"doc":"react_gleam/element","title":"td","content":"pub fn td(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.td\nreact_gleam/element td","url":"react_gleam/element.html#td"},{"doc":"react_gleam/element","title":"template","content":"pub fn template(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.template\nreact_gleam/element template","url":"react_gleam/element.html#template"},{"doc":"react_gleam/element","title":"text","content":"pub external fn text(content: String) -&gt; Element\n Render a Gleam string as an HTML text node.\n\nSynonyms:\nreact_gleam/element.text\nreact_gleam/element text","url":"react_gleam/element.html#text"},{"doc":"react_gleam/element","title":"textarea","content":"pub fn textarea(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.textarea\nreact_gleam/element textarea","url":"react_gleam/element.html#textarea"},{"doc":"react_gleam/element","title":"tfoot","content":"pub fn tfoot(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.tfoot\nreact_gleam/element tfoot","url":"react_gleam/element.html#tfoot"},{"doc":"react_gleam/element","title":"th","content":"pub fn th(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.th\nreact_gleam/element th","url":"react_gleam/element.html#th"},{"doc":"react_gleam/element","title":"thead","content":"pub fn thead(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.thead\nreact_gleam/element thead","url":"react_gleam/element.html#thead"},{"doc":"react_gleam/element","title":"time","content":"pub fn time(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.time\nreact_gleam/element time","url":"react_gleam/element.html#time"},{"doc":"react_gleam/element","title":"title","content":"pub fn title(attributes: List(Attribute(a, b)), name: String) -&gt; Element\n\nSynonyms:\nreact_gleam/element.title\nreact_gleam/element title","url":"react_gleam/element.html#title"},{"doc":"react_gleam/element","title":"tr","content":"pub fn tr(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.tr\nreact_gleam/element tr","url":"react_gleam/element.html#tr"},{"doc":"react_gleam/element","title":"track","content":"pub fn track(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.track\nreact_gleam/element track","url":"react_gleam/element.html#track"},{"doc":"react_gleam/element","title":"u","content":"pub fn u(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.u\nreact_gleam/element u","url":"react_gleam/element.html#u"},{"doc":"react_gleam/element","title":"ul","content":"pub fn ul(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.ul\nreact_gleam/element ul","url":"react_gleam/element.html#ul"},{"doc":"react_gleam/element","title":"var_","content":"pub fn var_(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.var_\nreact_gleam/element var_","url":"react_gleam/element.html#var_"},{"doc":"react_gleam/element","title":"video","content":"pub fn video(attributes: List(Attribute(a, b)), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nreact_gleam/element.video\nreact_gleam/element video","url":"react_gleam/element.html#video"},{"doc":"react_gleam/element","title":"wbr","content":"pub fn wbr(attributes: List(Attribute(a, b))) -&gt; Element\n\nSynonyms:\nreact_gleam/element.wbr\nreact_gleam/element wbr","url":"react_gleam/element.html#wbr"},{"doc":"react_gleam/element","title":"react_gleam/element","content":"","url":"react_gleam/element.html"},{"doc":"react_gleam","title":"Context","content":"pub external type Context\n\n\nSynonyms:\nreact_gleam.Context\nreact_gleam Context","url":"react_gleam.html#Context"},{"doc":"react_gleam","title":"component","content":"pub external fn component(element: fn() -&gt; Element) -&gt; Element\n\nSynonyms:\nreact_gleam.component\nreact_gleam component","url":"react_gleam.html#component"},{"doc":"react_gleam","title":"render","content":"pub external fn render(app: Element, root: String) -&gt; Nil\n\nSynonyms:\nreact_gleam.render\nreact_gleam render","url":"react_gleam.html#render"},{"doc":"react_gleam","title":"set_context","content":"pub external fn set_context(key: String, value: g) -&gt; Nil\n\nSynonyms:\nreact_gleam.set_context\nreact_gleam set_context","url":"react_gleam.html#set_context"},{"doc":"react_gleam","title":"react_gleam","content":"","url":"react_gleam.html"}]);